# ==============================================================================
# extract sigma.hat values
# ==============================================================================



sigma.hat.mi.method <- function(object,...){
    object@model$sigma
}
